@@ -21,6 +21,8 @@
 
 #include <X11/Xlib.h>
 
+#include "g2.h"
+
 typedef struct {
     Display     *display;
     Window      window;
@@ -83,7 +85,7 @@ int g2_X11_image(int pid, void *pdp,
 		 int x, int y, int width, int height, int *pen_array);
 int g2_X11_query_pointer(int pid, void *pdp,
 			 int *x, int *y, unsigned int *button);
-
+int g2_X11_get_pd_handles(int pid, void *pdp, void *handles[G2_PD_HANDLES_SIZE]);
 #endif /* _G2_X11_P_H */
 
 
